Aggregator.App.index\_query.IndexAggregator.get\_all\_CC\_indexes
=================================================================

.. currentmodule:: Aggregator.App.index_query

.. automethod:: IndexAggregator.get_all_CC_indexes